package com.cpxt.biz.service;

import com.cpxt.biz.domain.BizOrderTask;
import java.util.List;

/**
 * 订单任务Service接口
 * 
 * @author ruoyi
 * @date 2024-12-20
 */
public interface IBizOrderTaskService 
{
    /**
     * 查询订单任务
     * 
     * @param id 订单任务主键
     * @return 订单任务
     */
    public BizOrderTask selectBizOrderTaskById(Integer id);

    /**
     * 查询订单任务列表
     * 
     * @param bizOrderTask 订单任务
     * @return 订单任务集合
     */
    public List<BizOrderTask> selectBizOrderTaskList(BizOrderTask bizOrderTask);

    /**
     * 新增订单任务
     * 
     * @param bizOrderTask 订单任务
     * @return 结果
     */
    public int insertBizOrderTask(BizOrderTask bizOrderTask);

    /**
     * 修改订单任务
     * 
     * @param bizOrderTask 订单任务
     * @return 结果
     */
    public int updateBizOrderTask(BizOrderTask bizOrderTask);

    /**
     * 批量删除订单任务
     * 
     * @param ids 需要删除的订单任务主键集合
     * @return 结果
     */
    public int deleteBizOrderTaskByIds(Integer[] ids);

    /**
     * 删除订单任务信息
     * 
     * @param id 订单任务主键
     * @return 结果
     */
    public int deleteBizOrderTaskById(Integer id);

    void updateBizOrderTaskStatus(Long jobId,String status);
}
